personality_scores.RdArchival data from the Face Research Lab of a 5-factor personality questionnaire, with factor score calculated from personality.
personality_scores
A data frame with 15000 rows and 7 variables:
Each participant's unique ID
The date this questionnaire was completed
Mean score on Agreeableness items
Mean score on Conscientiousness items
Mean score on Extraversion items
Mean score on Neuroticism items
Mean score on Openness items
https://psyteachr.github.io/psyteachr/data/personality_scores.csv