getdata.RdSave data files to a directory
getdata(dir = "data", dataset = c("all", "dataskills"))
| dir | The name of the directory to save the data in (default "data") |
|---|---|
| dataset | Which dataset to download, from "all", "dataskills" (default "all") |
A list of the paths of the new data files